==> lein-polylith-0.3.jar: leiningen/polylith.clj <==
(ns leiningen.polylith
  (:require [leiningen.polylith.cmd :as cmd]
            [leiningen.polylith.file :as file]))

(defn- current-root-dir []
  (let [dir (file/current-path)]
    (println "Root directory not set, using current directory:" dir)
    (println "Root directory can be set in project.clj, e.g.:")
    (println "  {:polylith {:root-dir \"/Users/joakimtengstrand/projects/myproject\"")
    dir))

(defn ^:no-project-needed polylith
  {:help-arglists '([cmd/bcomponents
                     cmd/bsystems
                     cmd/components
                     cmd/deps
                     cmd/gitdiff
                     cmd/help
                     cmd/info
                     cmd/project-settings
                     cmd/systems])
   :subtasks [#'cmd/bcomponents
              #'cmd/bsystems
              #'cmd/components
              #'cmd/deps
              #'cmd/gitdiff
              #'cmd/help
              #'cmd/info
              #'cmd/project-settings
              #'cmd/systems]}
  ([project]
   (cmd/help))
  ([project subtask & args]
   (let [settings (:polylith project)
         root-dir (or (:root-dir settings) (current-root-dir))]
     (case subtask
       "bsystems" (cmd/bsystems root-dir)
       "bcomponents" (cmd/bcomponents root-dir args)
       "components" (cmd/components root-dir)
       "deps" (cmd/deps root-dir)
       "gitdiff" (cmd/gitdiff root-dir args)
       "help" (cmd/help)
       "info" (cmd/info root-dir args)
       "settings" (cmd/project-settings settings)
       "systems" (cmd/systems root-dir)
       (cmd/task-not-found subtask)))))

==> lein-polylith-0.4.jar: leiningen/polylith.clj <==
(ns leiningen.polylith
  (:require [leiningen.polylith.cmd :as cmd]
            [leiningen.polylith.file :as file]))

(defn- current-root-dir []
  (let [dir (file/current-path)]
    (println "Root directory not set, using current directory:" dir)
    dir))

(defn ^:no-project-needed polylith
  {:help-arglists '([cmd/bcomponents
                     cmd/bsystems
                     cmd/components
                     cmd/deps
                     cmd/gitdiff
                     cmd/help
                     cmd/info
                     cmd/project-settings
                     cmd/systems])
   :subtasks [#'cmd/bcomponents
              #'cmd/bsystems
              #'cmd/components
              #'cmd/deps
              #'cmd/gitdiff
              #'cmd/help
              #'cmd/info
              #'cmd/project-settings
              #'cmd/systems]}
  ([project]
   (cmd/help))
  ([project subtask & args]
   (println "####current dir:" (println (file/current-path)))
   (let [settings (:polylith project)
         root-dir (or (:root-dir settings) (current-root-dir))]
     (case subtask
       "bsystems" (cmd/bsystems root-dir)
       "bcomponents" (cmd/bcomponents root-dir args)
       "components" (cmd/components root-dir)
       "deps" (cmd/deps root-dir)
       "gitdiff" (cmd/gitdiff root-dir args)
       "help" (cmd/help)
       "info" (cmd/info root-dir args)
       "settings" (cmd/project-settings settings)
       "systems" (cmd/systems root-dir)
       (cmd/task-not-found subtask)))))
